aboutsummaryrefslogtreecommitdiffstats
path: root/contrib/libs/icu/i18n/rbt_data.h
diff options
context:
space:
mode:
authorromankoshelev <romankoshelev@yandex-team.com>2023-08-14 19:51:50 +0300
committerromankoshelev <romankoshelev@yandex-team.com>2023-08-15 01:24:11 +0300
commitcfcd865e05c0d0525ea27d1e153a043b32a85138 (patch)
tree68d3b3b25271e8a4998505897a269ff7ce119b76 /contrib/libs/icu/i18n/rbt_data.h
parentccb790c507bd5e8ffe2ef9886ce5ee0a7ce22a15 (diff)
downloadydb-cfcd865e05c0d0525ea27d1e153a043b32a85138.tar.gz
Update ICU to 73.2
Diffstat (limited to 'contrib/libs/icu/i18n/rbt_data.h')
-rw-r--r--contrib/libs/icu/i18n/rbt_data.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/contrib/libs/icu/i18n/rbt_data.h b/contrib/libs/icu/i18n/rbt_data.h
index 52a961dde0..43cbb4795b 100644
--- a/contrib/libs/icu/i18n/rbt_data.h
+++ b/contrib/libs/icu/i18n/rbt_data.h
@@ -67,7 +67,7 @@ public:
Hashtable variableNames;
/**
* Map category variable (UChar) to set (UnicodeFunctor).
* Variables that correspond to a set of characters are mapped
* from variable name to a stand-in character in data.variableNames.
* The stand-in then serves as a key in this hash to lookup the
@@ -91,7 +91,7 @@ public:
* variablesBase through variablesBase +
* variablesLength - 1 represent UnicodeFunctor objects.
*/
- UChar variablesBase;
+ char16_t variablesBase;
/**
* The length of variables.
@@ -118,7 +118,7 @@ public:
/**
* Given a stand-in character, return the UnicodeFunctor that it
- * represents, or NULL if it doesn't represent anything.
+ * represents, or nullptr if it doesn't represent anything.
* @param standIn the given stand-in character.
* @return the UnicodeFunctor that 'standIn' represents
*/
@@ -126,7 +126,7 @@ public:
/**
* Given a stand-in character, return the UnicodeMatcher that it
- * represents, or NULL if it doesn't represent anything or if it
+ * represents, or nullptr if it doesn't represent anything or if it
* represents something that is not a matcher.
* @param standIn the given stand-in character.
* @return return the UnicodeMatcher that 'standIn' represents
@@ -135,7 +135,7 @@ public:
/**
* Given a stand-in character, return the UnicodeReplacer that it
- * represents, or NULL if it doesn't represent anything or if it
+ * represents, or nullptr if it doesn't represent anything or if it
* represents something that is not a replacer.
* @param standIn the given stand-in character.
* @return return the UnicodeReplacer that 'standIn' represents
@@ -67,7 +67,7 @@ public:
Hashtable variableNames;
/**
- * Map category variable (UChar) to set (UnicodeFunctor).
+ * Map category variable (char16_t) to set (UnicodeFunctor).
* Variables that correspond to a set of characters are mapped
* from variable name to a stand-in character in data.variableNames.